from colored import fg
from PIL import Image
from terminalImgViewer.lib import reduce_resolution

CHAR = "■"

def getTerminalImage(image_path: string, width: int) -> string:
    im = reduce_resolution(Image.open(image_path).getdata().convert("RGB"), width)
    result = ""

    for i, pixel in enumerate(im):
        color = fg('#%02x%02x%02x' % pixel)
        result += color + CHAR * 2

        if (i + 1) % im.size[0] == 0:
            result += "\n"

    return result



from PIL import Image

def reduce_resolution(img, new_width):
    width, height = img.size
    reduction_factor = new_width / width
    new_height = int(height * reduction_factor)
    img = img.resize((new_width, new_height), Image.BOX)
    
    return img
